==> frontengine_dev-0.0.64-py3-none-any.whl: frontengine/utils/multi_language/simplified_chinese.py <==
simplified_chinese_word_dict = {
    # 菜單欄
    "menu_bar_language": "选择语言",
    "menu_bar_ui_style": "选择界面风格",
    # 语言菜单栏
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁体中文",
    "language_menu_bar_simplified_chinese": "简体中文",
    "language_menu_bar_germany": "德文",
    "language_menu_bar_russian": "俄罗斯文",
    "language_menu_bar_french": "法文",
    "language_menu_bar_italian": "意大利文",
    "language_menu_bar_please_restart_messagebox": "请重启以应用更改",
    # 标签文本
    "tab_video_text": "视频",
    "tab_image_text": "图片",
    "tab_web_text": "网页",
    "tab_gif_text": "GIF 和 WEBP",
    "tab_sound_text": "音乐",
    "tab_text_text": "文字",
    "tab_external_ui": "外部 UI",
    "tab_control_center_text": "控制中心",
    "chat_ui_text": "聊天",
    # 消息框文本
    "paint_gif_message_text": "GIF 或者 WEBP 文件有错误",
    "paint_image_message_box_text": "图片错误",
    "sound_effect_message_box_text": "音乐错误",
    "sound_player_message_box_text": "音乐错误",
    "video_player_message_box_text": "视频错误",
    "webview_message_box_text": "网页错误",
    "cant_find_extend_ui_message_box_text": "未找到 UI",
    # 控制中心 UI
    "control_center_close_all_video": "关闭全部视频",
    "control_center_close_all_image": "关闭全部图片",
    "control_center_close_all_gif": "关闭全部 GIF",
    "control_center_close_all_web": "关闭全部网页",
    "control_center_close_all_sound": "关闭全部音乐",
    "control_center_close_all_text": "关闭全部文字",
    "control_center_scene": "关闭场景",
    "control_center_clear_log_panel": "清除 Log",
    "chat_scene_close": "关闭所有聊天",
    "control_center_close_all": "关闭所有",
    # 常规
    "Opacity": "不透明度",
    "Speed": "速度",
    "Not Ready": "未准备好",
    "Ready": "已准备好",
    "Show on all screen": "显示在所有屏幕",
    "Volume": "音量",
    "Font size": "字体大小",
    "Play rate": "播放速度",
    "not_prepare": "尚未准备好",
    "Show on bottom": "显示在所有窗口底部",
    "url": "链接",
    "text": "文字",
    "ui_path": "UI 路径",
    "position_x": "X 坐标",
    "position_y": "Y 坐标",
    "seconds": "秒",
    "close_delay": "字幕消失时间 秒",
    "country_code": "区域代码",
    "show_on_which_monitor": "显示在哪个屏幕",
    "ok": "确定",
    "no": "否",
    # GIF 设置 UI
    "gif_setting_ui_choose_file": "选择 GIF 或 WEBP 文件",
    "gif_setting_ui_play": "开始播放 GIF 或 WEBP",
    "gif_setting_message_box": "请选择 GIF 或 WEBP 文件",
    # 图片设置 UI
    "image_setting_choose_file": "选择图片",
    "image_setting_ui_play": "开始播放图片",
    "image_setting_message_box": "请选择图片",
    # 音乐播放器设置 UI
    "sound_player_setting_choose_wav_file": "选择 wav 文件",
    "sound_player_setting_choose_sound_file": "请选择音档",
    "sound_player_setting_play_wav": "开始播放 wav",
    "sound_player_setting_play_sound": "开始播放音档",
    "sound_player_setting_message_box_wav": "请选择 wav 文件",
    "sound_player_setting_message_box_sound": "请选择音档",
    # 文字设置 UI
    "text_setting_start_draw": "开始在屏幕上绘制文字",
    "text_setting_choose_alignment": "选择文字排列方式",
    "text_setting_alignment_Top": "置顶",
    # 影片设置 UI
    "video_setting_choose_file": "选择视频",
    "video_setting_start_play": "开始播放视频",
    "video_setting_message_box": "请选择影片视频",
    # Web setting ui
    "web_setting_open_url": "用网址开启网页",
    "web_setting_open_local_file": "开启本地网页",
    "web_setting_open_enable_input": "启用输入",
    # Scene UI
    "tab_scene_text": "场景",
    "scene_start": "开始场景",
    "scene_table_view_type": "类型",
    "scene_file_path": "文件路径",
    "scene_setting_start_scene_button": "开始场景",
    "scene_add_image": "添加图片到场景",
    "scene_add_gif": "添加动图到场景",
    "scene_add_sound": "添加声音到场景",
    "scene_add_text": "添加文字到场景",
    "scene_add_video": "添加视频到场景",
    "scene_add_web": "添加网页到场景",
    "scene_url_label": "网址",
    "scene_add_UI": "添加UI到场景",
    "scene_choose_message_box": "请选择场景文件",
    "scene_choose_output_path_message_box": "请选择场景文件输出路径",
    "scene_output": "输出场景文件",
    "scene_input": "读取场景文件",
    "scene_script_clear": "清除所有脚本",
    "scene_script": "场景脚本",
    # Chat scene input
    "chat_scene_input_title": "输入聊天内容",
    "chat_scene_send_chat": "送出文字",
    # Chat scene
    "chat_scene_start_button": "开始聊天",
    "chat_scene_new_topic": "开始一个新话题",
    "chat_scene_creative": "创意",
    "chat_scene_precise": "精准",
    "chat_scene_balanced": "平衡",
    "chat_gpt_exception": "GPT 错误，请重试或开始一个新话题",
    "should_we_show_toast": "显示对话?",
    # Chat voice input
    "start_chat_voice_input_ui": "开启声音输入界面",
    "chat_recognizer_voice_button": "开始录制声音",
    # Image Generation
    "image_generation_tab": "图片生成",
    "start_generate_image": "开始生成图片",
    "input_error": "请勿无输入或空格",
    "save_generation_image": "储存图片",
    # Help Menu
    "help_menu_label": "帮助菜单",
    "help_menu_open_issue": "开启问题回报",
    "how_to_critical_exit_action": "怎么强制关闭",
    "how_to_critical_exit": "按下 F12 可以紧急关闭",
    # HowTo Menu
    "doc_menu_label": "文件菜单",
    "doc_menu_open_doc": "开启文件",
}

==> frontengine_dev-0.0.85-py3-none-any.whl: frontengine/utils/multi_language/simplified_chinese.py <==
simplified_chinese_word_dict = {
    # 菜單欄
    "menu_bar_language": "选择语言",
    "menu_bar_ui_style": "选择界面风格",
    # 语言菜单栏
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁体中文",
    "language_menu_bar_simplified_chinese": "简体中文",
    "language_menu_bar_germany": "德文",
    "language_menu_bar_russian": "俄罗斯文",
    "language_menu_bar_french": "法文",
    "language_menu_bar_italian": "意大利文",
    "language_menu_bar_please_restart_messagebox": "请重启以应用更改",
    # 标签文本
    "tab_video_text": "视频",
    "tab_image_text": "图片",
    "tab_web_text": "网页",
    "tab_gif_text": "GIF 和 WEBP",
    "tab_sound_text": "音乐",
    "tab_text_text": "文字",
    "tab_external_ui": "外部 UI",
    "tab_control_center_text": "控制中心",
    "chat_ui_text": "聊天",
    # 消息框文本
    "paint_gif_message_text": "GIF 或者 WEBP 文件有错误",
    "paint_image_message_box_text": "图片错误",
    "sound_effect_message_box_text": "音乐错误",
    "sound_player_message_box_text": "音乐错误",
    "video_player_message_box_text": "视频错误",
    "webview_message_box_text": "网页错误",
    "cant_find_extend_ui_message_box_text": "未找到 UI",
    # 控制中心 UI
    "control_center_close_all_video": "关闭全部视频",
    "control_center_close_all_image": "关闭全部图片",
    "control_center_close_all_gif": "关闭全部 GIF",
    "control_center_close_all_web": "关闭全部网页",
    "control_center_close_all_sound": "关闭全部音乐",
    "control_center_close_all_text": "关闭全部文字",
    "control_center_scene": "关闭场景",
    "control_center_clear_log_panel": "清除 Log",
    "chat_scene_close": "关闭所有聊天",
    "control_center_close_all": "关闭所有",
    # 常规
    "Opacity": "不透明度",
    "Speed": "速度",
    "Not Ready": "未准备好",
    "Ready": "已准备好",
    "Show on all screen": "显示在所有屏幕",
    "Volume": "音量",
    "Font size": "字体大小",
    "Play rate": "播放速度",
    "not_prepare": "尚未准备好",
    "Show on bottom": "显示在所有窗口底部",
    "url": "链接",
    "text": "文字",
    "ui_path": "UI 路径",
    "position_x": "X 坐标",
    "position_y": "Y 坐标",
    "seconds": "秒",
    "close_delay": "字幕消失时间 秒",
    "country_code": "区域代码",
    "show_on_which_monitor": "显示在哪个屏幕",
    "ok": "确定",
    "no": "否",
    "fullscreen_checkbox_label": "全屏?",
    # GIF 设置 UI
    "gif_setting_ui_choose_file": "选择 GIF 或 WEBP 文件",
    "gif_setting_ui_play": "开始播放 GIF 或 WEBP",
    "gif_setting_message_box": "请选择 GIF 或 WEBP 文件",
    # 图片设置 UI
    "image_setting_choose_file": "选择图片",
    "image_setting_ui_play": "开始播放图片",
    "image_setting_message_box": "请选择图片",
    # 音乐播放器设置 UI
    "sound_player_setting_choose_wav_file": "选择 wav 文件",
    "sound_player_setting_choose_sound_file": "请选择音档",
    "sound_player_setting_play_wav": "开始播放 wav",
    "sound_player_setting_play_sound": "开始播放音档",
    "sound_player_setting_message_box_wav": "请选择 wav 文件",
    "sound_player_setting_message_box_sound": "请选择音档",
    # 文字设置 UI
    "text_setting_start_draw": "开始在屏幕上绘制文字",
    "text_setting_choose_alignment": "选择文字排列方式",
    "text_setting_alignment_Top": "置顶",
    # 影片设置 UI
    "video_setting_choose_file": "选择视频",
    "video_setting_start_play": "开始播放视频",
    "video_setting_message_box": "请选择影片视频",
    # Web setting ui
    "web_setting_open_url": "用网址开启网页",
    "web_setting_open_local_file": "开启本地网页",
    "web_setting_open_enable_input": "启用输入",
    # Scene UI
    "tab_scene_text": "场景",
    "scene_start": "开始场景",
    "scene_table_view_type": "类型",
    "scene_file_path": "文件路径",
    "scene_setting_start_scene_button": "开始场景",
    "scene_add_image": "添加图片到场景",
    "scene_add_gif": "添加动图到场景",
    "scene_add_sound": "添加声音到场景",
    "scene_add_text": "添加文字到场景",
    "scene_add_video": "添加视频到场景",
    "scene_add_web": "添加网页到场景",
    "scene_url_label": "网址",
    "scene_add_UI": "添加UI到场景",
    "scene_choose_message_box": "请选择场景文件",
    "scene_choose_output_path_message_box": "请选择场景文件输出路径",
    "scene_output": "输出场景文件",
    "scene_input": "读取场景文件",
    "scene_script_clear": "清除所有脚本",
    "scene_script": "场景脚本",
    # Particle ui
    "tab_particle_text": "粒子",
    "choose_particle_direction": "选择粒子方向",
    "particle_setting_ui_play": "开始播放粒子",
    "particle_size": "粒子大小",
    "particle_count": "粒子数量",
    "particle_speed": "粒子速度",
    # Chat scene input
    "chat_scene_input_title": "输入聊天内容",
    "chat_scene_send_chat": "送出文字",
    # Chat scene
    "chat_scene_start_button": "开始聊天",
    "chat_scene_new_topic": "开始一个新话题",
    "chat_scene_creative": "创意",
    "chat_scene_precise": "精准",
    "chat_scene_balanced": "平衡",
    "chat_gpt_exception": "GPT 错误，请重试或开始一个新话题",
    "should_we_show_toast": "显示对话?",
    # Chat voice input
    "start_chat_voice_input_ui": "开启声音输入界面",
    "chat_recognizer_voice_button": "开始录制声音",
    # Image Generation
    "image_generation_tab": "图片生成",
    "start_generate_image": "开始生成图片",
    "input_error": "请勿无输入或空格",
    "save_generation_image": "储存图片",
    # Help Menu
    "help_menu_label": "帮助菜单",
    "help_menu_open_issue": "开启问题回报",
    "how_to_critical_exit_action": "怎么强制关闭",
    "how_to_critical_exit": "按下 F12 可以紧急关闭",
    # HowTo Menu
    "doc_menu_label": "文件菜单",
    "doc_menu_open_doc": "开启文件",
}
